@@ -12,15 +12,10 @@ class ETCJupyterLabNotebookStateProviderApp(ExtensionApp):
         except Exception as e:
             self.log.error(str(e))
 
-    def initialize_settings(self):
-        try:
-            self.log.info(f"Config {self.config}")
-        except Exception as e:
-            self.log.error(str(e))
-
     def initialize_handlers(self):
         try:
-            self.handlers.extend([(r'/etc-jupyterlab-notebook-state-provider/(.*)', RouteHandler)])
+            self.handlers.extend([(r"/etc-jupyterlab-notebook-state-provider/(.*)", RouteHandler)])
         except Exception as e:
             self.log.error(str(e))
+            raise e
 
